
## objective

Automate all repeatable tasks and write efficient well formatted code that both challenges and forges best practices.


## skills

**Languages:**  [golang](http://golang.org/), javascript, [python](https://www.python.org/), bash, c, c++, [php](http://php.net/), perl, java, action script, objective c

**Databases:**  [mariadb](https://mariadb.org/) / [mysql](http://www.mysql.com/), [mongodb](http://jquery.com/)

**Version Control:**  [git](http://git-scm.com/), [mercurial](http://mercurial.selenic.com/)

**Virtualization:**  [xen](https://www.virtualbox.org/), [virtualbox](https://www.virtualbox.org/), [parallels](http://www.parallels.com/), [vmware](http://www.vmware.com/), [vagrant](https://www.vagrantup.com/)

**Web and Proxy Servers:** [nginx](http://wiki.nginx.org/Main), [nodejs](http://nodejs.org/),  [apache](http://httpd.apache.org/)

**File Sharing:**  [samba](http://www.samba.org/), sshfs

**Configuration Management:**  [ansible](http://www.ansible.com/home), [chef](https://docs.chef.io/index.html), [puppet](https://docs.chef.io/index.html)

**Libraries and Frameworks:**  [jquery](http://jquery.com/), [backbone.js](http://backbonejs.org/), [zendframework 2](http://framework.zend.com/), [symfony](http://symfony.com/), [fuelphp](http://fuelphp.com/), [laravel](http://laravel.com/), [python gtk+3](https://developer.gnome.org/gtk3/stable/), [python telepathy glib](http://telepathy.freedesktop.org/doc/telepathy-glib/)

**Operation Systems:**  Linux ([debian](https://www.debian.org/), [fedora](https://getfedora.org/), [sugar](https://www.sugarlabs.org/), [arch](https://www.archlinux.org/), [ubuntu](http://www.ubuntu.com/), [mint](http://www.linuxmint.com/), [crunchbang](http://crunchbang.org/), [raspbian](http://www.raspbian.org/), [centos](http://www.centos.org/)) | Unix (OS X) | Windows (95 - 8.1)

**Architecture, Programming Design, and Development Practices:**  scalable architecture, continuous integration, server automation and configuration management, object oriented programming, design patterns, model view controller pattern, database normalization, database object relational model, nosql schema design, agile development, networking topology design, virtualization with iommu, optimizing virtual system kernels


## employment history

- **[hudl](http://www.hudl.com/), June 2014 - current**
    - assist in managing aws assets, including hundreds of web servers, and dozens of mongodb servers
    - help write, troubleshoot, and connect a myriad of glue-layer services for error reporting and alerting, deployment, and registered service management
- **[Stanley Gibbons](http://www.stanleygibbonsplc.com/), September 2013 - May 2014**
    - created php compatible image management service with scalable bash script for parallel execution to resize over 40 million images on an array of AWS EC2 images in under one business day
    - prepared custom vagrant ubuntu box with puppet, later converted to debian with bash for speed of execution
    - helped migrate [bidstart.com](http://www.bidstart.com/) from a single servint to multiple AWS EC2's
    - learned ZendFramework 2, Symfony, Puppet, Vagrant, GraphicsMagick/ImageMagick/Gd, Doctrine, and Mongodb in 6 months
- **[Google Summer of Code](http://www.google-melange.com/gsoc/homepage/google/gsoc2013), Summer 2013**
    - reopened a [video communication software](https://github.com/FOSSRIT/Open-Video-chat) project using Free and Open Source software tools for [XO Laptops](http://one.laptop.org/).
    - helped integrate port-support in the project for other linux distributions with [Gtk3](https://developer.gnome.org/gtk3/3.0/) and [telepathy](http://telepathy.freedesktop.org/wiki/)
    - held a [Sugarlabs (Makers of XO Operating system)](http://sugarlabs.org/) birds-of-a-feather hackathon in August during [Flock](http://flocktofedora.org/)
- **Freelance Developer & IT Consultant​ 2003 - current**
    - created numerous personal projects available on my [github account](https://github.com/CDeLorme)
    - created technical videos on [my youtube account](https://www.youtube.com/user/LordOfElm)
    - written a number of tutorials, guides, and articles on best practices on my portfolio website
    - provided consulting and web development services to small businesses
    - volunteer forum developer, host, & administrator for [seaofnumbers.com](http://seaofnumbers.com), coming from instantz.net and inpforums.com taken down in August 2012
- **[Martino Flynn](http://www.martinoflynn.com/), Developer Co-Op, Summer 2012**
    - designed the database, wireframes and infrastructure of the company intranet rebuild, including mobile services
    - rebuilt the intranet using [FuelPHP](http://fuelphp.com/), [jQuery](http://jquery.com/), and [Backbonejs](http://backbonejs.org/) including integrating a live notification system and issue tracker
    - helped rebuild sections of [amesbury.com](http://www.amesbury.com/), including an articles system and PDF locator.
    - maintained [absorbine.com](http://absorbine.com/) and optimized the [sphinx search engine](http://sphinxsearch.com/).
    - helped construct secure contact forms for [Segar Law](http://www.segarlaw.com/)
- **[Time Warner Cable](http://www.timewarnercable.com/en/residential.html), Rochester, NY, ​2009**
    - assisted callers by phone with their accounts and limited technical assistance
    - conceptualized and Prototyped web based system to improve order process efficiency
- **[ESL Federal Credit Union](https://www.esl.org/), Rochester, NY, ​​2008 - 2009**
    - assisted callers by phone with financial investments and loans
- **Washington Mutual Bank, Albion, NY, ​2006 – 2008**
    - assisted callers by phone with financial accounts
    - selected to teach a course on efficient use of the command line system to my peers
    - awarded employee of the month twice, and “Best of the ECC”, an award given annually to 12 out of over 1000 employees


## education

- [Rochester Institute of Technology](http://www.rit.edu/), Rochester NY
    - [Bachelor of Science in Information Technology](http://www.rit.edu/programs/information-technology-0)
    - Completed 2013, Dean’s List 3 Quarters
- [Monroe Community College](http://www.monroecc.edu/), Rochester NY
    - [Associates of Applied Science in Computer Information Systems](http://www.monroecc.edu/etsdbs/MCCatPub.nsf/AcademicPrograms/ComputerInformationSystems-AAS-DEGREE?OpenDocument)
    - Graduated 2010, Dean’s List 3 Semesters


## certifications

- [CompTIA](http://certification.comptia.org/home.aspx) IT Technician A+ Certified, July 2009


## other education

- High School Regents Diploma, [Norman Howard School](http://www.normanhoward.org/), Rochester, NY 2003
- Two Year Occupational Program in Computer Information Systems at [We-Mo-Co](http://www.monroe2boces.org/CTE.cfm), Ogden, NY 2003
- Accounted for a quarter of my graduation credits.


## personal

- A powerful thirst for knowledge and exceptional independent education skills.
- Adept problem solving skills, excelling in the implementation of unique solutions.
- Prefers working with groups in paired programming or team settings, recognizing that contributing brains is always beneficial.
- Enjoys challenging work, and experimenting with new technology.


## references

- [Mike Ruschak](http://mikeruschak.com/)
- [Remy DeCausemaker](https://www.linkedin.com/in/decause)
